pub struct ClientSmeReadApfPacketFilterDataResponse {
pub memory: Vec<u8>,
}Fields
memory: Vec<u8>Trait Implementations
Sourceimpl Clone for ClientSmeReadApfPacketFilterDataResponse
impl Clone for ClientSmeReadApfPacketFilterDataResponse
Sourcefn clone(&self) -> ClientSmeReadApfPacketFilterDataResponse
fn clone(&self) -> ClientSmeReadApfPacketFilterDataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<ClientSmeReadApfPacketFilterDataResponse, D> for ClientSmeReadApfPacketFilterDataResponse
impl<D: ResourceDialect> Decode<ClientSmeReadApfPacketFilterDataResponse, D> for ClientSmeReadApfPacketFilterDataResponse
Sourceimpl<D: ResourceDialect> Encode<ClientSmeReadApfPacketFilterDataResponse, D> for &ClientSmeReadApfPacketFilterDataResponse
impl<D: ResourceDialect> Encode<ClientSmeReadApfPacketFilterDataResponse, D> for &ClientSmeReadApfPacketFilterDataResponse
Sourceimpl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<ClientSmeReadApfPacketFilterDataResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<UnboundedVector<u8>, D>> Encode<ClientSmeReadApfPacketFilterDataResponse, D> for (T0,)
Sourceimpl Ord for ClientSmeReadApfPacketFilterDataResponse
impl Ord for ClientSmeReadApfPacketFilterDataResponse
Sourcefn cmp(&self, other: &ClientSmeReadApfPacketFilterDataResponse) -> Ordering
fn cmp(&self, other: &ClientSmeReadApfPacketFilterDataResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ClientSmeReadApfPacketFilterDataResponse
impl PartialEq for ClientSmeReadApfPacketFilterDataResponse
Sourcefn eq(&self, other: &ClientSmeReadApfPacketFilterDataResponse) -> bool
fn eq(&self, other: &ClientSmeReadApfPacketFilterDataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ClientSmeReadApfPacketFilterDataResponse
impl PartialOrd for ClientSmeReadApfPacketFilterDataResponse
Sourceimpl TypeMarker for ClientSmeReadApfPacketFilterDataResponse
impl TypeMarker for ClientSmeReadApfPacketFilterDataResponse
Sourcetype Owned = ClientSmeReadApfPacketFilterDataResponse
type Owned = ClientSmeReadApfPacketFilterDataResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for ClientSmeReadApfPacketFilterDataResponse
impl ValueTypeMarker for ClientSmeReadApfPacketFilterDataResponse
Sourcetype Borrowed<'a> = &'a ClientSmeReadApfPacketFilterDataResponse
type Borrowed<'a> = &'a ClientSmeReadApfPacketFilterDataResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Eq for ClientSmeReadApfPacketFilterDataResponse
impl Persistable for ClientSmeReadApfPacketFilterDataResponse
impl StructuralPartialEq for ClientSmeReadApfPacketFilterDataResponse